@@ -1,4 +1,5 @@
 var stylus = require('stylus'),
+    nib = require('nib'),
     source = '';
 
 process.stdin.resume();
@@ -9,7 +10,7 @@ process.stdin.on('data', function(chunk) {
 });
 
 process.stdin.on('end', function() {
-  var style = stylus(source, {filename: process.argv[2]});
+  var style = stylus(source, {filename: process.argv[2]}).use(nib());
   style.render(function(err, css) {
     if (err) {
       throw err;
